gotest

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 29, 2020 License: MIT Imports: 4 Imported by: 0

README

Overview

A tiny test framework for go projects. The test of this lib is its doc.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Each

func Each(t *testing.T, s interface{}, cb interface{})

Each runs each Exported method f on type s as a subtest of t. Function cb, the signature of it is:

cb(*testing.T) Case

Each f will be called with each Case that cb returns.

Types

type Assert

type Assert func(a, b interface{}, msg ...interface{})

Assert if a doesn't equal to b reports error with t.Error

func NewAssert

func NewAssert(t *testing.T) Assert

NewAssert creates an assert function

Jump to