package
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Sep 29, 2020
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Overview
A tiny test framework for go projects. The test of this lib is its doc.
Documentation
¶
func Each(t *testing.T, s interface{}, cb interface{})
Each runs each Exported method f on type s as a subtest of t.
Function cb, the signature of it is:
cb(*testing.T) Case
Each f will be called with each Case that cb returns.
type Assert func(a, b interface{}, msg ...interface{})
Assert if a doesn't equal to b reports error with t.Error
NewAssert creates an assert function
Source Files
¶
Click to show internal directories.
Click to hide internal directories.